pub struct ConvertAndReturnAs<T, U, V>(/* private fields */);Expand description
Return T through the FFI boundary by first converting it to U and then to V on the
host’s side, and then converting it back to U and then to T in the runtime.
This is useful to pass types when the conversion to/from FFI type cannot be implemented directly, e.g. because of the orphan rule.
Raw FFI type: same as V’s FFI type