pub trait RIType: Sized {
type FFIType: IntoValue + TryFromValue + WasmTy;
type Inner;
}Expand description
Something that can be used by the runtime interface as type to communicate between the runtime and the host.
Every type that should be used in a runtime interface function signature needs to implement this trait.
Required Associated Types
Sourcetype FFIType: IntoValue + TryFromValue + WasmTy
type FFIType: IntoValue + TryFromValue + WasmTy
The raw FFI type that is used to pass Self through the host <-> runtime boundary.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Implementors
Sourceimpl<T, U, V> RIType for ConvertAndReturnAs<T, U, V>where
V: RIType,
impl<T, U, V> RIType for ConvertAndReturnAs<T, U, V>where
V: RIType,
Sourceimpl<T, const N: usize> RIType for AllocateAndReturnPointer<T, N>
impl<T, const N: usize> RIType for AllocateAndReturnPointer<T, N>
Sourceimpl<T, const N: usize> RIType for PassPointerAndReadCopy<T, N>
impl<T, const N: usize> RIType for PassPointerAndReadCopy<T, N>
Sourceimpl<T, const N: usize> RIType for PassPointerAndWrite<T, N>
impl<T, const N: usize> RIType for PassPointerAndWrite<T, N>
Sourceimpl<T: PointerType> RIType for Pointer<T>
Available on non-substrate_runtime only.
impl<T: PointerType> RIType for Pointer<T>
Available on non-
substrate_runtime only.