FromFFIValue

Trait FromFFIValue 

pub trait FromFFIValue: Sized + RIType {
    // Required method
    fn from_ffi_value(arg: Self::FFIType) -> Self::Inner;
}
A type used as a return value in a host function. Can be created from an FFI value.

Implementations are safe to assume that the arg given to from_ffi_value is only generated by the corresponding host::IntoFFIValue implementation.

Required Methods

fn from_ffi_value(arg: Self::FFIType) -> Self::Inner

Create Self::Inner from the given FFI value.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors